@@ -8,7 +8,7 @@ readonly name="pybind11"
 readonly ownership="PyBind11 Upstream <robot@adios2>"
 readonly subtree="thirdparty/pybind11/pybind11"
 readonly repo="https://github.com/pybind/pybind11.git"
-readonly tag="master"
+readonly tag="stable"
 readonly shortlog="true"
 readonly paths="
   include/pybind11
